# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.administration.authenticated_user.v1 import authenticated_user_service_pb2 as qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2


class AuthenticatedUserStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDetails = channel.unary_unary(
                '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetDetails',
                request_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsResponse.FromString,
                )
        self.GetEnvironmentDetails = channel.unary_unary(
                '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetEnvironmentDetails',
                request_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsResponse.FromString,
                )
        self.GetCloudCredentials = channel.unary_unary(
                '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetCloudCredentials',
                request_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsResponse.FromString,
                )


class AuthenticatedUserServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDetails(self, request, context):
        """get authenticated user details for Login user only (not for application user)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironmentDetails(self, request, context):
        """get authenticated user's environment details
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCloudCredentials(self, request, context):
        """Get cloud credentials for login user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthenticatedUserServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDetails,
                    request_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsResponse.SerializeToString,
            ),
            'GetEnvironmentDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironmentDetails,
                    request_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsResponse.SerializeToString,
            ),
            'GetCloudCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCloudCredentials,
                    request_deserializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.administration.authenticated_user.v1.AuthenticatedUser', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthenticatedUser(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetDetails',
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsRequest.SerializeToString,
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironmentDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetEnvironmentDetails',
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsRequest.SerializeToString,
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetEnvironmentDetailsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCloudCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.authenticated_user.v1.AuthenticatedUser/GetCloudCredentials',
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsRequest.SerializeToString,
            qwak_dot_administration_dot_authenticated__user_dot_v1_dot_authenticated__user__service__pb2.GetCloudCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
