# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/environments/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/administration/v0/environments/configuration.proto\x12\x1fqwak.administration.environment\"\x82\x04\n\x1cQwakEnvironmentConfiguration\x12\x19\n\x11\x65\x64ge_services_url\x18\x01 \x01(\t\x12\x1d\n\x15management_access_url\x18\x06 \x01(\t\x12\x15\n\rmodel_api_url\x18\x02 \x01(\t\x12\x1e\n\x16\x61nalytics_data_api_url\x18\x03 \x01(\t\x12\x1d\n\x15object_storage_bucket\x18\x04 \x01(\t\x12\x19\n\x11\x62i_system_api_key\x18\x05 \x01(\t\x12T\n\x13\x63loud_configuration\x18\x07 \x01(\x0b\x32\x37.qwak.administration.environment.QwakCloudConfiguration\x12_\n\x1b\x66\x65\x61ture_store_configuration\x18\x08 \x01(\x0b\x32:.qwak.administration.environment.FeatureStoreConfiguration\x12!\n\x19\x63ontainer_registry_prefix\x18\t \x01(\t\x12]\n\x1a\x63ommunication_manager_type\x18\n \x01(\x0e\x32\x39.qwak.administration.environment.CommunicationManagerType\"v\n\x19\x46\x65\x61tureStoreConfiguration\x12\x1d\n\x15\x61irflow_connection_id\x18\x01 \x01(\t\x12\x15\n\rredis_address\x18\x02 \x01(\t\x12#\n\x1buser_code_execution_allowed\x18\x03 \x01(\x08\"\xdf\x01\n\x16QwakCloudConfiguration\x12Y\n\x17\x61ws_cloud_configuration\x18\x01 \x01(\x0b\x32\x36.qwak.administration.environment.AwsCloudConfigurationH\x00\x12Y\n\x17gcp_cloud_configuration\x18\x02 \x01(\x0b\x32\x36.qwak.administration.environment.GcpCloudConfigurationH\x00\x42\x0f\n\rconfiguration\"\xae\x01\n\x15\x41wsCloudConfiguration\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12K\n\x11\x66\x65\x61ture_store_emr\x18\x03 \x01(\x0b\x32\x30.qwak.administration.environment.FeatureStoreEmr\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x11\n\tworkgroup\x18\x05 \x01(\t\"\x91\x01\n\x15GcpCloudConfiguration\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12 \n\x18\x62ig_lake_connection_name\x18\x03 \x01(\t\x12\x19\n\x11\x62ig_lake_location\x18\x04 \x01(\t\x12\x17\n\x0fservice_account\x18\x05 \x01(\t\"\xc5\x01\n\x0f\x46\x65\x61tureStoreEmr\x12\x14\n\x0c\x65\x63\x32_key_name\x18\x01 \x01(\t\x12\x15\n\rec2_subnet_id\x18\x02 \x01(\t\x12\x19\n\x11\x65mr_job_flow_role\x18\x03 \x01(\t\x12\x18\n\x10\x65mr_service_role\x18\x04 \x01(\t\x12%\n\x1d\x65\x63\x32_additional_security_group\x18\x05 \x01(\t\x12)\n!target_on_demand_capacity_workers\x18\x06 \x01(\x05*X\n\x18\x43ommunicationManagerType\x12\x13\n\x0fINVALID_MANAGER\x10\x00\x12\x12\n\x0e\x44IRECT_MANAGER\x10\x01\x12\x13\n\x0f\x41\x44MIRAL_MANAGER\x10\x02\x42\xb2\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0b\x06proto3')

_COMMUNICATIONMANAGERTYPE = DESCRIPTOR.enum_types_by_name['CommunicationManagerType']
CommunicationManagerType = enum_type_wrapper.EnumTypeWrapper(_COMMUNICATIONMANAGERTYPE)
INVALID_MANAGER = 0
DIRECT_MANAGER = 1
ADMIRAL_MANAGER = 2


_QWAKENVIRONMENTCONFIGURATION = DESCRIPTOR.message_types_by_name['QwakEnvironmentConfiguration']
_FEATURESTORECONFIGURATION = DESCRIPTOR.message_types_by_name['FeatureStoreConfiguration']
_QWAKCLOUDCONFIGURATION = DESCRIPTOR.message_types_by_name['QwakCloudConfiguration']
_AWSCLOUDCONFIGURATION = DESCRIPTOR.message_types_by_name['AwsCloudConfiguration']
_GCPCLOUDCONFIGURATION = DESCRIPTOR.message_types_by_name['GcpCloudConfiguration']
_FEATURESTOREEMR = DESCRIPTOR.message_types_by_name['FeatureStoreEmr']
QwakEnvironmentConfiguration = _reflection.GeneratedProtocolMessageType('QwakEnvironmentConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _QWAKENVIRONMENTCONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.QwakEnvironmentConfiguration)
  })
_sym_db.RegisterMessage(QwakEnvironmentConfiguration)

FeatureStoreConfiguration = _reflection.GeneratedProtocolMessageType('FeatureStoreConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTORECONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.FeatureStoreConfiguration)
  })
_sym_db.RegisterMessage(FeatureStoreConfiguration)

QwakCloudConfiguration = _reflection.GeneratedProtocolMessageType('QwakCloudConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _QWAKCLOUDCONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.QwakCloudConfiguration)
  })
_sym_db.RegisterMessage(QwakCloudConfiguration)

AwsCloudConfiguration = _reflection.GeneratedProtocolMessageType('AwsCloudConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _AWSCLOUDCONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.AwsCloudConfiguration)
  })
_sym_db.RegisterMessage(AwsCloudConfiguration)

GcpCloudConfiguration = _reflection.GeneratedProtocolMessageType('GcpCloudConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _GCPCLOUDCONFIGURATION,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.GcpCloudConfiguration)
  })
_sym_db.RegisterMessage(GcpCloudConfiguration)

FeatureStoreEmr = _reflection.GeneratedProtocolMessageType('FeatureStoreEmr', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESTOREEMR,
  '__module__' : 'qwak.administration.v0.environments.configuration_pb2'
  # @@protoc_insertion_point(class_scope:qwak.administration.environment.FeatureStoreEmr)
  })
_sym_db.RegisterMessage(FeatureStoreEmr)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0'
  _COMMUNICATIONMANAGERTYPE._serialized_start=1480
  _COMMUNICATIONMANAGERTYPE._serialized_end=1568
  _QWAKENVIRONMENTCONFIGURATION._serialized_start=93
  _QWAKENVIRONMENTCONFIGURATION._serialized_end=607
  _FEATURESTORECONFIGURATION._serialized_start=609
  _FEATURESTORECONFIGURATION._serialized_end=727
  _QWAKCLOUDCONFIGURATION._serialized_start=730
  _QWAKCLOUDCONFIGURATION._serialized_end=953
  _AWSCLOUDCONFIGURATION._serialized_start=956
  _AWSCLOUDCONFIGURATION._serialized_end=1130
  _GCPCLOUDCONFIGURATION._serialized_start=1133
  _GCPCLOUDCONFIGURATION._serialized_end=1278
  _FEATURESTOREEMR._serialized_start=1281
  _FEATURESTOREEMR._serialized_end=1478
# @@protoc_insertion_point(module_scope)
