"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OnlineStreamingIngestion(google.protobuf.message.Message):
    """Online Ingestion"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name"]) -> None: ...

global___OnlineStreamingIngestion = OnlineStreamingIngestion

class OfflineStreamingIngestion(google.protobuf.message.Message):
    """Offline Ingestion"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    SCHEDULED_TRIGGER_FIELD_NUMBER: builtins.int
    MANUAL_TRIGGER_FIELD_NUMBER: builtins.int
    featureset_name: builtins.str
    @property
    def scheduled_trigger(self) -> global___ScheduledOfflineStreamingTrigger: ...
    @property
    def manual_trigger(self) -> global___ManualOfflineStreamingTrigger: ...
    def __init__(
        self,
        *,
        featureset_name: builtins.str = ...,
        scheduled_trigger: global___ScheduledOfflineStreamingTrigger | None = ...,
        manual_trigger: global___ManualOfflineStreamingTrigger | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["manual_trigger", b"manual_trigger", "scheduled_trigger", b"scheduled_trigger", "trigger_type", b"trigger_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_name", b"featureset_name", "manual_trigger", b"manual_trigger", "scheduled_trigger", b"scheduled_trigger", "trigger_type", b"trigger_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["trigger_type", b"trigger_type"]) -> typing_extensions.Literal["scheduled_trigger", "manual_trigger"] | None: ...

global___OfflineStreamingIngestion = OfflineStreamingIngestion

class ScheduledOfflineStreamingTrigger(google.protobuf.message.Message):
    """Scheduled offline ingestion (e.g., AirFlow)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ScheduledOfflineStreamingTrigger = ScheduledOfflineStreamingTrigger

class ManualOfflineStreamingTrigger(google.protobuf.message.Message):
    """Manual Offline ingestion (that is, someone manually running from the UI)"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ManualOfflineStreamingTrigger = ManualOfflineStreamingTrigger
