"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.administration.v0.users.user_pb2
import qwak.self_service.account.v0.account_membership_pb2
import qwak.self_service.user.v1.user_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ListAccountUserProfilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAccountUserProfilesRequest = ListAccountUserProfilesRequest

class ListAccountUserProfilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PROFILES_FIELD_NUMBER: builtins.int
    @property
    def user_profiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.user.v1.user_pb2.UserProfile]:
        """All account users"""
    def __init__(
        self,
        *,
        user_profiles: collections.abc.Iterable[qwak.self_service.user.v1.user_pb2.UserProfile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_profiles", b"user_profiles"]) -> None: ...

global___ListAccountUserProfilesResponse = ListAccountUserProfilesResponse

class UpdateUserRoleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ROLE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """User ID"""
    account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType
    """User account role"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_role", b"account_role", "id", b"id"]) -> None: ...

global___UpdateUserRoleRequest = UpdateUserRoleRequest

class UpdateUserRoleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def user_profile(self) -> qwak.self_service.user.v1.user_pb2.UserProfile:
        """All account users"""
    def __init__(
        self,
        *,
        user_profile: qwak.self_service.user.v1.user_pb2.UserProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> None: ...

global___UpdateUserRoleResponse = UpdateUserRoleResponse

class UpdateUserAssignedEnvironmentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_IDS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """User ID"""
    @property
    def environment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """User bound environments"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        environment_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_ids", b"environment_ids", "id", b"id"]) -> None: ...

global___UpdateUserAssignedEnvironmentsRequest = UpdateUserAssignedEnvironmentsRequest

class UpdateUserAssignedEnvironmentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def user_profile(self) -> qwak.self_service.user.v1.user_pb2.UserProfile:
        """All account users"""
    def __init__(
        self,
        *,
        user_profile: qwak.self_service.user.v1.user_pb2.UserProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_profile", b"user_profile"]) -> None: ...

global___UpdateUserAssignedEnvironmentsResponse = UpdateUserAssignedEnvironmentsResponse

class RemoveUserFromAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """User ID"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___RemoveUserFromAccountRequest = RemoveUserFromAccountRequest

class RemoveUserFromAccountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemoveUserFromAccountResponse = RemoveUserFromAccountResponse

class InviteToJoinAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.InviteOptions]:
        """Options for new invitations"""
    def __init__(
        self,
        *,
        options: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.InviteOptions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["options", b"options"]) -> None: ...

global___InviteToJoinAccountRequest = InviteToJoinAccountRequest

class InviteToJoinAccountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATIONS_FIELD_NUMBER: builtins.int
    @property
    def invitations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription]: ...
    def __init__(
        self,
        *,
        invitations: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitations", b"invitations"]) -> None: ...

global___InviteToJoinAccountResponse = InviteToJoinAccountResponse

class UpdateInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ROLE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_IDS_FIELD_NUMBER: builtins.int
    invitation_id: builtins.str
    """Id of the invitation"""
    account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType
    """User account role"""
    @property
    def environment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Bind user to environments"""
    def __init__(
        self,
        *,
        invitation_id: builtins.str = ...,
        account_role: qwak.administration.v0.users.user_pb2.QwakAccountRole.ValueType = ...,
        environment_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_role", b"account_role", "environment_ids", b"environment_ids", "invitation_id", b"invitation_id"]) -> None: ...

global___UpdateInvitationRequest = UpdateInvitationRequest

class UpdateInvitationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_FIELD_NUMBER: builtins.int
    @property
    def invitation(self) -> qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription: ...
    def __init__(
        self,
        *,
        invitation: qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["invitation", b"invitation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitation", b"invitation"]) -> None: ...

global___UpdateInvitationResponse = UpdateInvitationResponse

class AcceptInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_ID_FIELD_NUMBER: builtins.int
    invitation_id: builtins.str
    """Id of the invitation"""
    def __init__(
        self,
        *,
        invitation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitation_id", b"invitation_id"]) -> None: ...

global___AcceptInvitationRequest = AcceptInvitationRequest

class AcceptInvitationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AcceptInvitationResponse = AcceptInvitationResponse

class CancelJoiningInvitationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATION_ID_FIELD_NUMBER: builtins.int
    invitation_id: builtins.str
    """Id of the invitation"""
    def __init__(
        self,
        *,
        invitation_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitation_id", b"invitation_id"]) -> None: ...

global___CancelJoiningInvitationRequest = CancelJoiningInvitationRequest

class CancelJoiningInvitationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CancelJoiningInvitationResponse = CancelJoiningInvitationResponse

class ListAccountInvitationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListAccountInvitationsRequest = ListAccountInvitationsRequest

class ListAccountInvitationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATIONS_FIELD_NUMBER: builtins.int
    @property
    def invitations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription]: ...
    def __init__(
        self,
        *,
        invitations: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitations", b"invitations"]) -> None: ...

global___ListAccountInvitationsResponse = ListAccountInvitationsResponse

class ListUserInvitationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListUserInvitationsRequest = ListUserInvitationsRequest

class ListUserInvitationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITATIONS_FIELD_NUMBER: builtins.int
    @property
    def invitations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription]: ...
    def __init__(
        self,
        *,
        invitations: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitations", b"invitations"]) -> None: ...

global___ListUserInvitationsResponse = ListUserInvitationsResponse

class ListUserMembershipsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListUserMembershipsRequest = ListUserMembershipsRequest

class ListUserMembershipsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ACCOUNTS_FIELD_NUMBER: builtins.int
    INVITATIONS_FIELD_NUMBER: builtins.int
    @property
    def user_accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.UserAccountDescription]: ...
    @property
    def invitations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription]: ...
    def __init__(
        self,
        *,
        user_accounts: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.UserAccountDescription] | None = ...,
        invitations: collections.abc.Iterable[qwak.self_service.account.v0.account_membership_pb2.JoiningInvitationDescription] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["invitations", b"invitations", "user_accounts", b"user_accounts"]) -> None: ...

global___ListUserMembershipsResponse = ListUserMembershipsResponse
