"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.feature_store.v1.common.source_code.source_code_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class FeaturesetAttributes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_CODE_SPEC_FIELD_NUMBER: builtins.int
    @property
    def source_code_spec(self) -> qwak.feature_store.v1.common.source_code.source_code_pb2.SourceCodeSpec:
        """Featureset source code"""
    def __init__(
        self,
        *,
        source_code_spec: qwak.feature_store.v1.common.source_code.source_code_pb2.SourceCodeSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_code_spec", b"source_code_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_code_spec", b"source_code_spec"]) -> None: ...

global___FeaturesetAttributes = FeaturesetAttributes
