# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/alerting.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/kube_deployment_captain/alerting.proto\x12\x1cqwak.kube.deployment.captain\"3\n\x07\x43hannel\x12\x12\n\nchannel_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"f\n\x13\x46\x65\x61tureSetAlertType\x12G\n\x07\x66\x61ilure\x18\x01 \x01(\x0b\x32\x34.qwak.kube.deployment.captain.FeatureSetFailureAlertH\x00\x42\x06\n\x04type\"Q\n\x16\x46\x65\x61tureSetFailureAlert\x12\x37\n\x08\x63hannels\x18\x01 \x03(\x0b\x32%.qwak.kube.deployment.captain.Channel\"\xbc\x01\n\x16\x46\x65\x61tureSetAlertOptions\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x46\n\x0b\x61lert_types\x18\x05 \x03(\x0b\x32\x31.qwak.kube.deployment.captain.FeatureSetAlertTypeB+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')



_CHANNEL = DESCRIPTOR.message_types_by_name['Channel']
_FEATURESETALERTTYPE = DESCRIPTOR.message_types_by_name['FeatureSetAlertType']
_FEATURESETFAILUREALERT = DESCRIPTOR.message_types_by_name['FeatureSetFailureAlert']
_FEATURESETALERTOPTIONS = DESCRIPTOR.message_types_by_name['FeatureSetAlertOptions']
Channel = _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), {
  'DESCRIPTOR' : _CHANNEL,
  '__module__' : 'qwak.kube_deployment_captain.alerting_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.Channel)
  })
_sym_db.RegisterMessage(Channel)

FeatureSetAlertType = _reflection.GeneratedProtocolMessageType('FeatureSetAlertType', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETALERTTYPE,
  '__module__' : 'qwak.kube_deployment_captain.alerting_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.FeatureSetAlertType)
  })
_sym_db.RegisterMessage(FeatureSetAlertType)

FeatureSetFailureAlert = _reflection.GeneratedProtocolMessageType('FeatureSetFailureAlert', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETFAILUREALERT,
  '__module__' : 'qwak.kube_deployment_captain.alerting_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.FeatureSetFailureAlert)
  })
_sym_db.RegisterMessage(FeatureSetFailureAlert)

FeatureSetAlertOptions = _reflection.GeneratedProtocolMessageType('FeatureSetAlertOptions', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESETALERTOPTIONS,
  '__module__' : 'qwak.kube_deployment_captain.alerting_pb2'
  # @@protoc_insertion_point(class_scope:qwak.kube.deployment.captain.FeatureSetAlertOptions)
  })
_sym_db.RegisterMessage(FeatureSetAlertOptions)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _CHANNEL._serialized_start=77
  _CHANNEL._serialized_end=128
  _FEATURESETALERTTYPE._serialized_start=130
  _FEATURESETALERTTYPE._serialized_end=232
  _FEATURESETFAILUREALERT._serialized_start=234
  _FEATURESETFAILUREALERT._serialized_end=315
  _FEATURESETALERTOPTIONS._serialized_start=318
  _FEATURESETALERTOPTIONS._serialized_end=506
# @@protoc_insertion_point(module_scope)
